pycocoa.windows.TextWindow

Package pycocoa :: Module windows :: Class TextWindow |
[frames] | no frames]

# Class TextWindow

      object --+
               |
    bases._Type0 --+
                   |
        bases._Type1 --+
                       |
            bases._Type2 --+
                           |
                      Window --+
                               |
                              TextWindow

Scrollable text window Python Type, wrapping ObjC `NSWindow/NSView`.

Instance Methods
__init__(self, text_or_file, font=None, title=`'``Text``'`, fraction=0.5, **kwds) Create a TextWindow. |
Inherited from `Window`: `cascade`, `close`, `front`, `full`, `hide`, `limit`, `windowCloseOK_`, `windowClose_`, `windowKey_`, `windowMain_`, `windowPrint_`, `windowResize_`, `windowScreen_`, `windowZoomOK_`, `zoom` Inherited from `bases._Type2`: `__str__` Inherited from `bases._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Window`: `NSview`, `PMview`, `alpha`, `frame`, `isBuiltIn`, `isExternal`, `isFull`, `isFullScreen`, `isHidden`, `isKey`, `isMain`, `isPrintable`, `isVisible`, `isZoomed`, `opaque`, `ratio`, `screen`, `transparent`, `transparentTitlebar` Inherited from `bases._Type2`: `title` Inherited from `bases._Type1`: `NSdelegate`, `app` Inherited from `bases._Type0`: `NS`, `NSDelegate`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__(self, text_or_file, font=None, title=`'``Text``'`, fraction=0.5, **kwds) (Constructor) |
Create a TextWindow. Parameters: `text_or_file` - The contents (`str` or `file`). `font` - Optional font (Font), default `Fonts.MonoSpace`. `title` - Window name or title (`str`). `fraction` - Window size as fraction of the screen (`float`). `kwds` - Optional, additional keyword arguments, see Window. Raises: `WindowError` - Unique `Id` exists. Overrides: object.__init__